@@ -3,7 +3,7 @@
  * The LDAP class attempts to change a user's password stored in an LDAP
  * directory service.
  *
- * $Horde: passwd/lib/Driver/ldap.php,v 1.41.2.7 2009/01/21 19:46:56 chuck Exp $
+ * $Horde: passwd/lib/Driver/ldap.php,v 1.41.2.12 2009-09-18 14:31:58 jan Exp $
  *
  * Copyright 2000-2009 The Horde Project (http://www.horde.org/)
  *
@@ -87,6 +87,12 @@ class Passwd_Driver_ldap extends Passwd_Driver {
             }
         }
 
+        if (!empty($this->_params['referrals'])) {
+            if (!ldap_set_option($this->_ds, LDAP_OPT_REFERRALS, $this->_params['referrals'])) {
+                return PEAR::raiseError(_("Unable to disable directory referrals"));
+            }
+        }
+
         return true;
     }
 
@@ -121,16 +127,24 @@ class Passwd_Driver_ldap extends Passwd_Driver {
      * @param string $username      The user for which to change the password.
      * @param string $old_password  The old (current) user password.
      * @param string $new_password  The new user password to set.
+     * @param string $userdn        Will be set to the retrieved user DN.
      *
      * @return boolean  True or PEAR_Error based on success of the change.
      */
-    function changePassword($username, $old_password, $new_password)
+    function changePassword($username, $old_password, $new_password, &$userdn)
     {
         // See if the old password matches before allowing the change
         if ($old_password !== Auth::getCredential('password')) {
             return PEAR::raiseError(_("Incorrect old password."));
         }
 
+        // Bind as current user. _connect will try as guest if no user realm
+        // is found or auth error.
+        $result = $this->_connect();
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
+        }
+
         // Append realm as username@realm if 'realm' parameter is set.
         if (!empty($this->_params['realm'])) {
             $username .= '@' . $this->_params['realm'];
@@ -139,10 +153,10 @@ class Passwd_Driver_ldap extends Passwd_Driver {
         // Get the user's dn.
         if ($GLOBALS['conf']['hooks']['userdn']) {
             $userdn = Horde::callHook('_passwd_hook_userdn',
-                                      array(Auth::getAuth()),
+                                      array($username),
                                       'passwd');
         } else {
-            $userdn = $this->_lookupdn($username);
+            $userdn = $this->_lookupdn($username, $old_password);
             if (is_a($userdn, 'PEAR_Error')) {
                 return $userdn;
             }
@@ -198,7 +212,7 @@ class Passwd_Driver_ldap extends Passwd_Driver {
             $new_details[$this->_params['shadowlastchange']] = floor(time() / 86400);
         }
 
-        if (!ldap_mod_replace($this->_ds, $userdn, $new_details)) {
+        if (!@ldap_mod_replace($this->_ds, $userdn, $new_details)) {
             return PEAR::raiseError(ldap_error($this->_ds));
         }
 
@@ -213,21 +227,11 @@ class Passwd_Driver_ldap extends Passwd_Driver {
      *
      * @param string $user    The username of the user.
      * @param string $passw   The password of the user.
-     * @param string $realm   The realm (domain) name of the user.
-     * @param string $basedn  The ldap basedn.
-     * @param string $uid     The ldap uid.
      *
      * @return string  The ldap dn for the user.
      */
-    function _lookupdn($user)
+    function _lookupdn($user, $passw)
     {
-        // Bind as current user. _connect will try as guest if no user realm
-        // is found or auth error.
-        $result = $this->_connect();
-        if (is_a($result, 'PEAR_Error')) {
-            return $result;
-        }
-
         // Search as an admin if so configured
         if (!empty($this->_params['admindn'])) {
             $this->_bind($this->_params['admindn'], $this->_params['adminpw']);
@@ -249,6 +253,17 @@ class Passwd_Driver_ldap extends Passwd_Driver {
             return PEAR::raiseError(_("User not found."));
         }
 
+        // If we used admin bindings, we have to check the password here.
+        if (!empty($this->_params['admindn'])) {
+            $ldappasswd = ldap_get_values($this->_ds, $entry,
+                                          $this->_params['attribute']);
+            $result = $this->comparePasswords($ldappasswd[0], $passw);
+            if (is_a($result, 'PEAR_Error')) {
+                return $result;
+            }
+        }
+
         return ldap_get_dn($this->_ds, $entry);
     }
+
 }
